@@ -45,7 +45,7 @@ def test_default_headers(client):
 
 
 def test_normalize_url_remove_angular_extension_in_client():
-    """ Tests if the url extension '#/' is removed when initializing the Client """
+    """Tests if the url extension '#/' is removed when initializing the Client"""
     client = Client("http://some-machine/health-discovery/#/", api_token=TEST_API_TOKEN)
     assert client._url == "http://some-machine/health-discovery/"
 
@@ -53,16 +53,16 @@ def test_normalize_url_remove_angular_extension_in_client():
 def test_build_url():
     client = Client("http://some-machine/health-discovery/", api_token=TEST_API_TOKEN)
     assert (
-            client._build_url("v1/some-endpoint/")
-            == "http://some-machine/health-discovery/rest/v1/some-endpoint/"
+        client._build_url("v1/some-endpoint/")
+        == "http://some-machine/health-discovery/rest/v1/some-endpoint/"
     )
 
 
 def test_build_url_encode_url():
     client = Client("http://some-machine/health-discovery/", api_token=TEST_API_TOKEN)
     assert (
-            client._build_url("v1/some-endpoint/Special URL ä ö # ! ? ³")
-            == "http://some-machine/health-discovery/rest/v1/some-endpoint/Special%20URL%20%C3%A4%20%C3%B6%20%23%20%21%20%3F%20%C2%B3"
+        client._build_url("v1/some-endpoint/Special URL ä ö # ! ? ³")
+        == "http://some-machine/health-discovery/rest/v1/some-endpoint/Special%20URL%20%C3%A4%20%C3%B6%20%23%20%21%20%3F%20%C2%B3"
     )
 
 
@@ -87,7 +87,7 @@ def test_upload_license(client, requests_mock):
     payload = {
         "valid": True,
         "expirationDateInMillis": 1753962034965,
-        "expirationDate": "Thu Jul 31 13:40:34 CEST 2025"
+        "expirationDate": "Thu Jul 31 13:40:34 CEST 2025",
     }
 
     requests_mock.get(
@@ -97,9 +97,9 @@ def test_upload_license(client, requests_mock):
             "payload": {
                 "specVersion": "7.5.0",
                 "buildNumber": "branch: main f2731e315ee137cf94c48e5f2fa431777fe49cef",
-                "platformVersion": "8.21.0"
+                "platformVersion": "8.21.0",
             },
-            "errorMessages": []
+            "errorMessages": [],
         },
     )
 
@@ -121,9 +121,9 @@ def test_list_resource_containers_not_supported(client, requests_mock):
             "payload": {
                 "specVersion": "7.6.0",
                 "buildNumber": "branch: main f2731e315ee137cf94c48e5f2fa431777fe49cef",
-                "platformVersion": "8.22.0"
+                "platformVersion": "8.22.0",
             },
-            "errorMessages": []
+            "errorMessages": [],
         },
     )
     with pytest.raises(OperationNotSupported):
@@ -138,9 +138,9 @@ def test_list_resource_containers(client, requests_mock):
             "payload": {
                 "specVersion": "7.7.0",
                 "buildNumber": "branch: main f2731e315ee137cf94c48e5f2fa431777fe49cef",
-                "platformVersion": "8.23.0"
+                "platformVersion": "8.23.0",
             },
-            "errorMessages": []
+            "errorMessages": [],
         },
     )
 
@@ -148,16 +148,9 @@ def test_list_resource_containers(client, requests_mock):
         f"{API_EXPERIMENTAL}/textanalysis/containers",
         headers={"Content-Type": "application/json"},
         json={
-            "payload": {
-                "containers": [
-                    {
-                        "name": "container",
-                        "scope": "GLOBAL"
-                    }
-                ]
-            },
-            "errorMessages": []
-        }
+            "payload": {"containers": [{"name": "container", "scope": "GLOBAL"}]},
+            "errorMessages": [],
+        },
     )
 
     actual_containers = client.list_resource_containers()
@@ -174,9 +167,9 @@ def test_create_resource_container(client, requests_mock):
             "payload": {
                 "specVersion": "7.7.0",
                 "buildNumber": "branch: main f2731e315ee137cf94c48e5f2fa431777fe49cef",
-                "platformVersion": "8.23.0"
+                "platformVersion": "8.23.0",
             },
-            "errorMessages": []
+            "errorMessages": [],
         },
     )
 
@@ -188,22 +181,14 @@ def test_create_resource_container(client, requests_mock):
                 "containerName": "container",
                 "scope": "GLOBAL",
                 "resources": [
-                    {
-                        "relativePath": "text3.txt"
-                    },
-                    {
-                        "relativePath": "text2.txt"
-                    },
-                    {
-                        "relativePath": "text1.txt"
-                    },
-                    {
-                        "relativePath": "sub/text4.txt"
-                    }
-                ]
+                    {"relativePath": "text3.txt"},
+                    {"relativePath": "text2.txt"},
+                    {"relativePath": "text1.txt"},
+                    {"relativePath": "sub/text4.txt"},
+                ],
             },
-            "errorMessages": []
-        }
+            "errorMessages": [],
+        },
     )
 
     resource_zip_file = Path(TEST_DIRECTORY) / "resources" / "zip_test" / "zip_test.zip"
@@ -849,7 +834,9 @@ def test_concept_autosuggest(client, requests_mock):
         },
         "errorMessages": [],
     }
-    endpoint = f"terminology/projects/{project_name}/terminologies/{terminology_name}/conceptAutosuggest"
+    endpoint = (
+        f"terminology/projects/{project_name}/terminologies/{terminology_name}/conceptAutosuggest"
+    )
     full_url = f"{API_EXPERIMENTAL}/{endpoint}"
     requests_mock.post(full_url, json=response_json)
 
@@ -873,14 +860,14 @@ def test_analyse_text(client, requests_mock):
                     "begin": 28,
                     "end": 40,
                     "type": "de.averbis.types.health.Diagnosis",
-                    "coveredText": "Appendizitis"
+                    "coveredText": "Appendizitis",
                     # ... truncated ...
                 },
                 {
                     "begin": 28,
                     "end": 40,
                     "type": "de.averbis.textanalysis.types.health.Diagnosis",
-                    "coveredText": "Appendizitis"
+                    "coveredText": "Appendizitis",
                     # ... truncated ...
                 },
             ],
@@ -915,7 +902,7 @@ def test_analyse_texts_with_some_working_and_some_failing(client_version_5, requ
                         "begin": 0,
                         "end": len(doc_text),
                         "type": "uima.tcas.DocumentAnnotation",
-                        "coveredText": doc_text
+                        "coveredText": doc_text,
                         # ... truncated ...
                     },
                 ],
@@ -1124,6 +1111,10 @@ def test_handle_error_outside_platform(client, requests_mock):
         client._Client__request_with_json_response(method="get", endpoint=f"v1/invalid_url")
     expected_error_message = "404 Server Error: 'Not found' for url: 'https://localhost:8080/information-discovery/rest/v1/invalid_url'."
     assert str(ex.value) == expected_error_message
+    assert ex.value.reason == "Not found"
+    assert ex.value.status_code == 404
+    assert ex.value.url == "https://localhost:8080/information-discovery/rest/v1/invalid_url"
+    assert ex.value.error_message is None
 
 
 def test_handle_error_in_non_existing_endpoint(client, requests_mock):
@@ -1142,6 +1133,10 @@ def test_handle_error_in_non_existing_endpoint(client, requests_mock):
         client._Client__request_with_json_response(method="get", endpoint="v1/invalid_url")
     expected_error_message = "404 Server Error: 'None' for url: 'https://localhost:8080/information-discovery/rest/v1/invalid_url'.\nPlatform error message is: 'Not Found'"
     assert str(ex.value) == expected_error_message
+    assert ex.value.reason is None
+    assert ex.value.status_code == 404
+    assert ex.value.url == "https://localhost:8080/information-discovery/rest/v1/invalid_url"
+    assert ex.value.error_message == "Platform error message is: 'Not Found'"
 
 
 def test_handle_error_bad_request(client, requests_mock):
@@ -1159,6 +1154,10 @@ def test_handle_error_bad_request(client, requests_mock):
         "Endpoint error message is: 'A project with name 'test' already exists.'"
     )
     assert str(ex.value) == expected_error_message
+    assert ex.value.reason is None
+    assert ex.value.status_code == 400
+    assert ex.value.url == "https://localhost:8080/information-discovery/rest/v1/invalid_url"
+    assert ex.value.error_message == "Endpoint error message is: 'A project with name 'test' already exists.'"
 
 
 def test_handle_error_no_access(client, requests_mock):
@@ -1170,6 +1169,10 @@ def test_handle_error_no_access(client, requests_mock):
         )
     expected_error_message = "401 Server Error: 'None' for url: 'https://localhost:8080/information-discovery/rest/v1/url/that/cannot/be/accessed'."
     assert str(ex.value) == expected_error_message
+    assert ex.value.reason is None
+    assert ex.value.status_code == 401
+    assert ex.value.url == "https://localhost:8080/information-discovery/rest/v1/url/that/cannot/be/accessed"
+    assert ex.value.error_message is None
 
 
 def test_upload_resources(client_version_6, requests_mock):
@@ -1253,13 +1256,23 @@ def test_create_zip_io__folder(client):
 
 def test_annotation_types_normalization(client):
     normalized = client._preprocess_annotation_types(["custom.Diagnosis", "custom.Medication"])
-    assert normalized == "custom.Diagnosis,custom.Medication" or normalized == "custom.Medication,custom.Diagnosis"  # order is not fixed
-    assert client._preprocess_annotation_types("custom.Diagnosis, custom.Medication") == "custom.Diagnosis,custom.Medication"
+    assert (
+        normalized == "custom.Diagnosis,custom.Medication"
+        or normalized == "custom.Medication,custom.Diagnosis"
+    )  # order is not fixed
+    assert (
+        client._preprocess_annotation_types("custom.Diagnosis, custom.Medication")
+        == "custom.Diagnosis,custom.Medication"
+    )
     assert client._preprocess_annotation_types(None) is None
 
 
 def test_evaluation_configuration_constructor_handles_kwargs():
-    eval_config = EvaluationConfiguration("de.averbis.types.health.diagnosis", features_to_compare=["begin", "end"], projectAnnotationsTo="de.averbis.extraction.types.Token")
+    eval_config = EvaluationConfiguration(
+        "de.averbis.types.health.diagnosis",
+        features_to_compare=["begin", "end"],
+        projectAnnotationsTo="de.averbis.extraction.types.Token",
+    )
     assert eval_config.projectAnnotationsTo == "de.averbis.extraction.types.Token"
 
 
